==> netsa-io-silk_2.12-1.5.3-sources.jar: CompressionMethod.scala <==
// Copyright 2015-2022 by Carnegie Mellon University
// See license information in LICENSE.txt

package org.cert.netsa.io.silk

import enumeratum.values.{ByteEnum, ByteEnumEntry}

/**
  * A SiLK compression method. May be converted to and from
  * [[scala.Byte Byte]] values.
  *
  * See [[CompressionMethod$ the companion object]] for more details.
  *
  * @param value The byte value representing this compression method.
  */
sealed abstract class CompressionMethod(val value: Byte) extends ByteEnumEntry

case object CompressionMethod extends ByteEnum[CompressionMethod] {

  /**
    * Collection of all known valid compression methods.
    * @group Members
    */
  lazy val values = findValues
  // Note: lazy to avoid cyclic initialization problem

  /** Converts a byte value to a compression method.
    * @return The compression method represented by this value.
    * @throws SilkDataFormatException
    *     if the byte represents no known compression method.
    * @group Members
    */
  def apply(v: Byte): CompressionMethod = withValueOpt(v) match {
    case Some(method) => method
    case None =>
      throw new SilkDataFormatException(
        s"Unrecognized compression method $v")
  }

  /**
    * SiLK compression method for no compression.
    * @group Values
    */
  case object NONE extends CompressionMethod(0)
  /**
    * SiLK compression method for zlib compression.
    * @group Values
    */
  case object ZLIB extends CompressionMethod(1)
  /**
    * SiLK compression method for lzo compression.
    * @group Values
    */
  case object LZO1X extends CompressionMethod(2)
  /**
    * SiLK compression method for snappy compression.
    * @group Values
    */
  case object SNAPPY extends CompressionMethod(3)
}

// @LICENSE_FOOTER@
//
// Copyright 2015-2022 Carnegie Mellon University. All Rights Reserved.
//
// This material is based upon work funded and supported by the
// Department of Defense and Department of Homeland Security under
// Contract No. FA8702-15-D-0002 with Carnegie Mellon University for the
// operation of the Software Engineering Institute, a federally funded
// research and development center sponsored by the United States
// Department of Defense. The U.S. Government has license rights in this
// software pursuant to DFARS 252.227.7014.
//
// NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE ENGINEERING
// INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS" BASIS. CARNEGIE MELLON
// UNIVERSITY MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR
// IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT LIMITED TO, WARRANTY OF
// FITNESS FOR PURPOSE OR MERCHANTABILITY, EXCLUSIVITY, OR RESULTS
// OBTAINED FROM USE OF THE MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT
// MAKE ANY WARRANTY OF ANY KIND WITH RESPECT TO FREEDOM FROM PATENT,
// TRADEMARK, OR COPYRIGHT INFRINGEMENT.
//
// Released under a GNU GPL 2.0-style license, please see LICENSE.txt or
// contact permission@sei.cmu.edu for full terms.
//
// [DISTRIBUTION STATEMENT A] This material has been approved for public
// release and unlimited distribution. Please see Copyright notice for
// non-US Government use and distribution.
//
// Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent and
// Trademark Office by Carnegie Mellon University.
//
// This software includes and/or makes use of third party software each
// subject to its own license as detailed in LICENSE-thirdparty.tx
//
// DM20-1143

==> netsa-io-silk_2.12-1.6.0-sources.jar: CompressionMethod.scala <==
// Copyright 2015-2022 by Carnegie Mellon University
// See license information in LICENSE.txt

package org.cert.netsa.io.silk

import enumeratum.values.{ByteEnum, ByteEnumEntry}
import java.lang.{Byte => JByte}

/**
  * A SiLK compression method. May be converted to and from
  * [[scala.Byte Byte]] values.
  *
  * See [[CompressionMethod$ the companion object]] for more details.
  *
  * @param value The byte value representing this compression method.
  */
sealed abstract class CompressionMethod(val value: Byte)
  extends ByteEnumEntry
{
  def toByte: Byte = value
  def toInt: Int = JByte.toUnsignedInt(value)
}

case object CompressionMethod extends ByteEnum[CompressionMethod] {

  /**
    * Collection of all known valid compression methods.
    * @group Members
    */
  lazy val values = findValues
  // Note: lazy to avoid cyclic initialization problem

  /** Converts a byte value to a compression method.
    * @return The compression method represented by this value.
    * @throws SilkDataFormatException
    *     if the byte represents no known compression method.
    * @group Members
    */
  def apply(v: Byte): CompressionMethod = withValueOpt(v) match {
    case Some(method) => method
    case None =>
      throw new SilkDataFormatException(
        s"Unrecognized compression method $v")
  }

  /**
    * SiLK compression method for no compression.
    * @group Values
    */
  case object NONE extends CompressionMethod(0)
  /**
    * SiLK compression method for zlib compression.
    * @group Values
    */
  case object ZLIB extends CompressionMethod(1)
  /**
    * SiLK compression method for lzo compression.
    * @group Values
    */
  case object LZO1X extends CompressionMethod(2)
  /**
    * SiLK compression method for snappy compression.
    * @group Values
    */
  case object SNAPPY extends CompressionMethod(3)
}

// @LICENSE_FOOTER@
//
// Copyright 2015-2022 Carnegie Mellon University. All Rights Reserved.
//
// This material is based upon work funded and supported by the
// Department of Defense and Department of Homeland Security under
// Contract No. FA8702-15-D-0002 with Carnegie Mellon University for the
// operation of the Software Engineering Institute, a federally funded
// research and development center sponsored by the United States
// Department of Defense. The U.S. Government has license rights in this
// software pursuant to DFARS 252.227.7014.
//
// NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE ENGINEERING
// INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS" BASIS. CARNEGIE MELLON
// UNIVERSITY MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR
// IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT LIMITED TO, WARRANTY OF
// FITNESS FOR PURPOSE OR MERCHANTABILITY, EXCLUSIVITY, OR RESULTS
// OBTAINED FROM USE OF THE MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT
// MAKE ANY WARRANTY OF ANY KIND WITH RESPECT TO FREEDOM FROM PATENT,
// TRADEMARK, OR COPYRIGHT INFRINGEMENT.
//
// Released under a GNU GPL 2.0-style license, please see LICENSE.txt or
// contact permission@sei.cmu.edu for full terms.
//
// [DISTRIBUTION STATEMENT A] This material has been approved for public
// release and unlimited distribution. Please see Copyright notice for
// non-US Government use and distribution.
//
// Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent and
// Trademark Office by Carnegie Mellon University.
//
// This software includes and/or makes use of third party software each
// subject to its own license as detailed in LICENSE-thirdparty.tx
//
// DM20-1143
